@@ -5,25 +5,18 @@ use strict;
 use Time::HiRes qw(time);
 use Graphics::Framebuffer;
 
-my $mali = 0;
-my $file = 0;
+my $f = Graphics::Framebuffer->new('FILE_MODE' => 0,'FB_DEVICE' => '/dev/fb0');
 
-my $arg = join('',@ARGV);
-$mali = 1 if ($arg =~ /mali/i); # Mali GPU correction mode
-$file = 1 if ($arg =~ /file/i); # File Handle drawing mode
+my $fm = Graphics::Framebuffer->new('FILE_MODE' => 1,'FB_DEVICE' => '/dev/fb0','SPLASH' => 0);
 
-my $f = Graphics::Framebuffer->new('MALI' => $mali);
-
-my $fm = Graphics::Framebuffer->new('FILE_MODE' => $file,'MALI' => $mali,'FB_DEVICE' => '/dev/fb0');
-
-$f->cls();
+$f->cls('OFF');
 my @t;
 my $x = $f->{'XRES'} / 2;
 my $y = $f->{'YRES'} / 2;
 my $start = time;
 
 $f->set_color({'red' => 255,'green' => 0,'blue' => 0});
-foreach my $radius (10 .. $y) {
+for( my $radius = 10; $radius < $y; $radius += 4) {
     $f->circle({'x' => $x, 'y' => $y, 'radius' => $radius, 'filled' => 1});
 }
 
@@ -32,7 +25,7 @@ push(@t,sprintf('%.02f',time-$start));
 $start = time;
 
 $fm->set_color({'red' => 0,'green' => 0,'blue' => 255});
-foreach my $radius (10 .. $y) {
+for( my $radius = 10; $radius < $y; $radius += 4) {
     $fm->circle({'x' => $x, 'y' => $y, 'radius' => $radius, 'filled' => 1});
 }
 
@@ -70,5 +63,6 @@ foreach my $xx (0..$f->{'XRES'}) {
     $fm->line({'x' => $xx,'y' => 0,'xx' => $xx, 'yy' => $f->{'YRES'}});
 }
 push(@t,sprintf('%.02f',time-$start));
+$f->cls('ON');
 
 print "CIRCLE STRING: $t[0]\n  CIRCLE FILE: $t[1]\n   BOX STRING: $t[2]\n     BOX FILE: $t[3]\n  LINE STRING: $t[4]\n    LINE FILE: $t[5]\n\n";
